pub struct LiveLocationsObserver { /* private fields */ }Expand description
Tracks active live location shares in a room using an ObservableVector.
Registers event handlers for beacon (location update) and beacon info
(share started/stopped) events and reflects changes into a vector that
callers can subscribe to via LiveLocationsObserver::subscribe.
Event handlers are automatically unregistered when this struct is dropped.
Implementations
Sourceimpl LiveLocationsObserver
impl LiveLocationsObserver
Sourcepub fn subscribe(
&self,
) -> (Vector<LiveLocationShare>, VectorSubscriberBatchedStream<LiveLocationShare>)
pub fn subscribe( &self, ) -> (Vector<LiveLocationShare>, VectorSubscriberBatchedStream<LiveLocationShare>)
Subscribe to changes and updates in the live location shares.
Returns a snapshot of the current items alongside a batched stream of
eyeball_im::VectorDiffs that describe subsequent changes.